# starlite-users

Authentication, authorization and user management for the Starlite framework

## _This package is not yet production ready._

## Features

- Supports Session, JWT and JWTCookie authentication backends
- Authorization via role based guards
- Pre-configured route handlers for:
  - Authentication
  - Registration
  - Verification
  - Password reset
  - Administrative user management (read, update, delete)
  - Administrative role management (read, update, delete)
  - Assignment/revocation of roles to/from users

## Getting started

### Installation

`pip install starlite-users`

### Documentation

[Read the documentation](https://lonelyvikingmichael.github.io/starlite-users/)

Otherwise [check out the examples](https://github.com/LonelyVikingMichael/starlite-users/tree/main/examples)
